@@ -32,12 +32,6 @@ def GetSegmentIDs(PDBDataFrame):
     SegmentSet = PDBDataFrame.segment_id.unique()
     return SegmentSet
 def EuclideanDistance(coords1, coords2):
-    if type(coords1) and type(coords2) is list:
-        coords1 = numpy.array(coords1)
-        coords2 = numpy.array(coords2)
-    if type(coords1) and type(coords2) is tuple:
-        coords1 = numpy.array(list(coords1))
-        coords2 = numpy.array(list(coords2))
     return numpy.linalg.norm(coords1-coords2)
 
 
@@ -354,10 +348,12 @@ def FindPotentialClashes(PDBDataFrame, Atom1Name, Atom2Name, DistanceLimit):
     Histogram = plt.hist(Distances)
     plt.xlabel(Atom1Name+  "-"+ Atom2Name +  " Distances up to " +str(DistanceLimit) + " angstroms")
     return Histogram, pandas.DataFrame(Distances)
-def CheckAllPotentialClashes(PDBDataFrame):
+def CheckAllPotentialClashes(PDBDataFrame, Save = False, FileName = None):
     distances = [2.4, 2.9, 2.9, 2.75, 3.4,3.22, 3.25, 3.04, 3.07, 3.1]
     for count, clash in enumerate(list(combinations_with_replacement("HCON", 2))):
         FindPotentialClashes(PDBDataFrame, clash[0], clash[1], distances[count])
+        if Save:
+            plt.savefig(f"{FileName} {clash[0]}-{clash[1]} Potential Clashes.png", facecolor = "w")
         plt.show()
 def FindParavastuFunction(SearchString):
     paravastu_functions = dir(labmodule)
